# Tersel

Tersel stands for **Ter**minal **Sel**ector.

---
[tersel](https://github.com/thijnmens/tersel) © 2024 by [Thijn Smulders](https://https://github.com/thijnmens) is
licensed under [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/)